@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import *
+from django.conf.urls.defaults import patterns, url
 
 urlpatterns = patterns('libthumbor.django.views',
     url("^$", 'generate_url', name="generate_thumbor_url"),
