@@ -53,13 +53,15 @@ def url_for(**options):
 
 def unsafe_url(**options):
     '''Returns the unsafe url with the specified options'''
+
+    return 'unsafe/%s' % plain_image_url(**options)
+
+def plain_image_url(**options):
     url_parts = get_url_parts(**options)
     url_parts.append(options['image_url'])
-    url_parts.insert(0, 'unsafe')
 
     return '/'.join(url_parts)
 
-
 def get_url_parts(**options):
     if 'image_url' not in options:
         raise ValueError('The image_url argument is mandatory.')
@@ -69,6 +71,15 @@ def get_url_parts(**options):
     if options.get('meta', False):
         url_parts.append('meta')
 
+    trim = options.get('trim', None)
+    if trim:
+        bits = ['trim']
+        if not isinstance(trim, bool):
+            bits.append(trim[0] if trim[0] else '')
+            if trim[1]:
+                bits.append(str(trim[1]))
+        url_parts.append(':'.join(bits))
+
     crop = options.get('crop', None)
     if crop:
         crop_left = crop[0][0]
@@ -92,10 +103,10 @@ def get_url_parts(**options):
     valign = options.get('valign', 'middle')
 
     if not halign in AVAILABLE_HALIGN:
-        raise ValueError('Only "left", "center" and "right" are' + \
+        raise ValueError('Only "left", "center" and "right" are' +
                          ' valid values for horizontal alignment.')
     if not valign in AVAILABLE_VALIGN:
-        raise ValueError('Only "top", "middle" and "bottom" are' + \
+        raise ValueError('Only "top", "middle" and "bottom" are' +
                          ' valid values for vertical alignment.')
 
     if halign != 'center':
